@@ -237,11 +237,11 @@ class SAML2Plugin(BasePlugin):
             if session.has_key(self.session_storedurl_key):
                 session.delete(self.session_storedurl_key)
             request.response.redirect(storedurl)
-            r = scl.artifact2message(request.form['SAMLart'], 'idpsso')
+            r = scl.artifact2message(request.form.pop('SAMLart'), 'idpsso')
             logger.info(r.text)
             if r.status_code == 200:
                 try:
-                    response = scl.parse_artifact_resolve_response(r.text)
+                    response = scl.parse_artifact_resolve_response(r.text.encode(r.encoding))
                     response.attribute_converters = scl.config.attribute_converters
                     response.assertion = response.assertion[0]
                     response.ava = get_identity(response)
